## Release Notes for 2.1 Beta 1

Released on 30 July 2023

This is a beta release of the next release version, and is intended for testing purposes. Please be careful when using this version on live writing projects, and make sure you take frequent backups.

Please check the changelog for an overview of changes. The full release notes will be added to the final release.

See also the Releases page.